@@ -3,10 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         Scripts/condor/submitbatchjob.sh
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -26,50 +26,58 @@
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-if [ $# -lt 2 ] ; then
-   echo usage: $0 jobWorkingDirectory jobDescriptionFile
+if [ $# -lt 3 ] ; then
+   echo usage: $0 jobWorkingDirectory jobScratchDirectory jobDescriptionFile
    exit 64
 fi
 
-cd $1
+jobWorkingDirectory=$1
+jobScratchDirectory=$2
+jobDescriptionFile=$3
+
+binPath=$(readlink -f $(dirname $0))
+export PATH=${binPath}:${PATH}
+
+cd ${jobWorkingDirectory}
 exitStatus=$?
 
-if [ $exitStatus -eq 0 ] ; then
-   case $2 in
+if [ ${exitStatus} -eq 0 ] ; then
+   case ${jobDescriptionFile} in
       *.condor)
-         JOBID=`condor_submit $2`
+         JOBID=`condor_submit ${jobDescriptionFile}`
          exitStatus=$?
-         if [ $# -gt 2 ] ; then
+         if [ $# -gt 3 ] ; then
             logRecord=`date`
-            shift 2
+            shift 3
             while [ $# -gt 0 ] ; do
                logRecord=${logRecord}'\t'$1
                shift 1
             done
             logRecord=${logRecord}'\t'${JOBID}
-            echo -e ${logRecord} >> condorlog
+            echo -e ${logRecord} >> ${HOME}/condorlog
          fi
          ;;
       *.pegasus)
-         export CONDOR_CONFIG=/var/condor/Grid/etc/condor_config
-         export PATH=/var/condor/Condor/@CONDORVERSION@/bin:${PATH}
-         . /etc/environ.sh
-         use -e -r pegasus-@PEGASUSVERSION@
-         JOBID=`$2`
+         if [ -x /local/proxy/bin/personalize-proxy.sh ] ; then
+            /local/proxy/bin/personalize-proxy.sh
+         fi
+         JOBID=`${jobDescriptionFile}`
          exitStatus=$?
+         if [ ${exitStatus} -eq 0 ] ; then
+            nohup movepegtmp2home.sh ${jobWorkingDirectory} ${jobScratchDirectory} > /dev/null 2>&1 &
+         fi
          ;;
       *)
-         echo "Invalid job class $2"
+         echo "Invalid job class ${jobDescriptionFile}"
          exitStatus=23
          ;;
    esac
 fi
 
-if [ $exitStatus -eq 0 ] ; then
+if [ ${exitStatus} -eq 0 ] ; then
    echo "${JOBID}"
 else
    echo "-1"
 fi
 
-exit $exitStatus
-
+exit ${exitStatus}
