@@ -3,10 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         Scripts/ll/killbatchjob.sh
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -31,16 +31,18 @@ if [ $# -ne 2 ] ; then
    exit 64
 fi
 
-case $2 in
+jobId=$1
+jobClass=$2
+
+case ${jobClass} in
    LL)
-      llcancel $1
+      llcancel ${jobId}
       exitStatus=$?
       ;;
    *)
-      echo "Invalid job class $2"
+      echo "Invalid job class ${jobClass}"
       exitStatus=23
       ;;
 esac
 
-exit $exitStatus
-
+exit ${exitStatus}
